==> myfaces-tobago-5.7.0-source-release.zip: tobago-5.7.0/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/AriasUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.renderkit.html;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.lang.reflect.Field;

public class AriasUnitTest {

  @Test
  public void testAttributeNames() throws IllegalAccessException {
    for (final Field field : Arias.class.getFields()) {

      final Arias aria = (Arias) field.get(null);
      final String value = aria.getValue();
      Assertions.assertTrue(value.matches("aria-[a-z0-9]+"), "Regexp check: value='" + aria + "'");

      final String extension = value.substring("aria-".length());
      final String name = field.getName();
      Assertions.assertEquals(name, extension.toUpperCase());
    }
  }

}

==> myfaces-tobago-6.7.0-source-release.zip: tobago-6.7.0/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/AriasUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.renderkit.html;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.lang.reflect.Field;
import java.util.Locale;

public class AriasUnitTest {

  @Test
  public void testAttributeNames() throws IllegalAccessException {
    for (final Field field : Arias.class.getFields()) {

      final Arias aria = (Arias) field.get(null);
      final String value = aria.getValue();
      Assertions.assertTrue(value.matches("aria-[a-z0-9]+"), "Regexp check: value='" + aria + "'");

      final String extension = value.substring("aria-".length());
      final String name = field.getName();
      Assertions.assertEquals(name, extension.toUpperCase(Locale.ROOT));
    }
  }

}
